==> haskell-mutable-containers-0.3.4.1-191-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mutable-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mutable-containers
version:              0.3.4.1
visibility:           public
id:                   mutable-containers-0.3.4.1-GTQBu6qu28wF6SQEJhKvq
key:                  mutable-containers-0.3.4.1-GTQBu6qu28wF6SQEJhKvq
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Abstactions and concrete implementations of mutable containers

description:
    See docs and README at <http://www.stackage.org/package/mutable-containers>

category:             Data
abi:                  c664ab8588b228a15f65ade996f58380
exposed:              True
exposed-modules:      Data.Mutable
hidden-modules:
    Data.Mutable.BRef Data.Mutable.Class Data.Mutable.Deque
    Data.Mutable.DLList Data.Mutable.PRef Data.Mutable.SRef
    Data.Mutable.URef Paths_mutable_containers

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mutable-containers-0.3.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mutable-containers-0.3.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mutable-containers-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mutable-containers
hs-libraries:         HSmutable-containers-0.3.4.1-GTQBu6qu28wF6SQEJhKvq
depends:
    base-4.17.2.1 containers-0.6.7 ghc-prim-0.9.1
    mono-traversable-1.0.21.0-ADindLcKBOgGsqwGBIy6UA
    primitive-0.9.1.0-3qHntBOAe4Y4he61Fs3OAc
    vector-0.13.2.0-K0fBmK5qd7y3388236ZS0A

haddock-interfaces:
    /usr/share/doc/haskell-mutable-containers/html/mutable-containers.haddock

haddock-html:         /usr/share/doc/haskell-mutable-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mutable-containers-0.3.4.1-192-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mutable-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mutable-containers
version:              0.3.4.1
visibility:           public
id:                   mutable-containers-0.3.4.1-802mI3jRSR34xFe8m3GTNy
key:                  mutable-containers-0.3.4.1-802mI3jRSR34xFe8m3GTNy
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Abstactions and concrete implementations of mutable containers

description:
    See docs and README at <http://www.stackage.org/package/mutable-containers>

category:             Data
abi:                  8791735ae9e56a8e0da8e1a85dcc3f90
exposed:              True
exposed-modules:      Data.Mutable
hidden-modules:
    Data.Mutable.BRef Data.Mutable.Class Data.Mutable.Deque
    Data.Mutable.DLList Data.Mutable.PRef Data.Mutable.SRef
    Data.Mutable.URef Paths_mutable_containers

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mutable-containers-0.3.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mutable-containers-0.3.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mutable-containers-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mutable-containers
hs-libraries:         HSmutable-containers-0.3.4.1-802mI3jRSR34xFe8m3GTNy
depends:
    base-4.17.2.1 containers-0.6.7 ghc-prim-0.9.1
    mono-traversable-1.0.21.0-6NjCHZJKev8LRd9XTre2A1
    primitive-0.9.1.0-2rF1KRuV9tjItame9gIzcT
    vector-0.13.2.0-L6HpF7nmtGm1K7R40olL6U

haddock-interfaces:
    /usr/share/doc/haskell-mutable-containers/html/mutable-containers.haddock

haddock-html:         /usr/share/doc/haskell-mutable-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
